summaryrefslogtreecommitdiffstats
path: root/korn/dcopdrop.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/dcopdrop.h')
-rw-r--r--korn/dcopdrop.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/korn/dcopdrop.h b/korn/dcopdrop.h
index 91bc8f98d..32e85066d 100644
--- a/korn/dcopdrop.h
+++ b/korn/dcopdrop.h
@@ -105,7 +105,7 @@ public:
*
* @return true is all information is retrieved succesfully.
*/
- virtual bool readConfigGroup( const QMap< QString, QString > & map, const Protocol * protocol );
+ virtual bool readConfigGroup( const TQMap< TQString, TQString > & map, const Protocol * protocol );
/**
* This function writes the information to a config group.
*
@@ -118,7 +118,7 @@ public:
*
* @return "dcop"
*/
- virtual QString type() const;
+ virtual TQString type() const;
/**
* This function should return true if it uses a synchrone comminucation.
@@ -137,9 +137,9 @@ public:
/**
* This function does reads the subjects.
* @param stop A variable which isn't used: only used for synchrone actions
* @return A QValueVector which KornMailSubject* instance for every new mail.
*/
- virtual QValueVector< KornMailSubject >* doReadSubjects( bool *stop );
+ virtual TQValueVector< KornMailSubject >* doReadSubjects( bool *stop );
/**
* This function should return true if it is possible to delete emails.
@@ -155,7 +155,7 @@ public:
* @param stop Not used: only for synchrone opererations.
* @return true if deleting was succesfull
*/
- virtual bool deleteMails( QPtrList<const KornMailId> * ids, bool * stop );
+ virtual bool deleteMails( TQPtrList<const KornMailId> * ids, bool * stop );
/**
* This function returns true if it is possible to read emails.
@@ -168,8 +168,8 @@ public:
private:
bool _isRunning;
- QMap< int, KornMailSubject* > *_msgList;
- QString *_name;
+ TQMap< int, KornMailSubject* > *_msgList;
+ TQString *_name;
int _counter;
DCOPDropInterface *_interface;
@@ -179,12 +179,12 @@ private slots:
void doReadSubjectsASync( void );
public: //accessed by DCOPDropInterface
- int addMessage( const QString& subject, const QString& message );
+ int addMessage( const TQString& subject, const TQString& message );
bool removeMessage( int id );
//accessed by DCOPDropCfg
- QString DCOPName() const;
- void setDCOPName( const QString& );
+ TQString DCOPName() const;
+ void setDCOPName( const TQString& );
};
#endif
@@ -137,9 +137,9 @@ public:
* This function does reads the subjects.
* @param stop A variable which isn't used: only used for synchrone actions
- * @return A QValueVector which KornMailSubject* instance for every new mail.
+ * @return A TQValueVector which KornMailSubject* instance for every new mail.
*/